@@ -22,7 +22,7 @@ class VectorHeat1D(Vector):
 
         :param size: number of spatial degrees of freedom
         """
-        super(VectorHeat1D, self).__init__()
+        super().__init__()
         self.size = size
         self.values = np.zeros(size)
 
@@ -48,6 +48,17 @@ class VectorHeat1D(Vector):
         tmp.set_values(self.get_values() - other.get_values())
         return tmp
 
+    def __mul__(self, other):
+        """
+        Multiplication of one vector object with a float (self and other)
+
+        :param other: object to be multiplied with self
+        :return: difference of vector object self and input object other
+        """
+        tmp = VectorHeat1D(self.size)
+        tmp.set_values(self.get_values() * other)
+        return tmp
+
     def norm(self):
         """
         Norm of a vector object
@@ -56,6 +67,16 @@ class VectorHeat1D(Vector):
         """
         return np.linalg.norm(self.values)
 
+    def clone(self):
+        """
+        Clone vector object
+
+        :rtype: vector object with zero values
+        """
+        tmp = VectorHeat1D(self.size)
+        tmp.set_values(self.get_values())
+        return tmp
+
     def clone_zero(self):
         """
         Initialize vector object with zeros
@@ -90,6 +111,22 @@ class VectorHeat1D(Vector):
         """
         return self.values
 
+    def pack(self):
+        """
+        Pack data
+
+        :return: values of vector object
+        """
+        return self.values
+
+    def unpack(self, values):
+        """
+        Unpack and set data
+
+        :param values: values for vector object
+        """
+        self.values = values
+
 
 class Heat1D(Application):
     """
@@ -110,7 +147,7 @@ class Heat1D(Application):
         :param rhs: right-hand side
         """
 
-        super(Heat1D, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         # Spatial domain with homogeneous Dirichlet boundary conditions
         self.x_start = x_start
         self.x_end = x_end
